@@ -1,4 +1,4 @@
-from typing import Any, Dict, Iterator, List, Optional, Union, cast, overload
+from typing import Any, Dict, Iterator, List, Optional, Sequence, Union, cast, overload
 
 from cognite.client._api_client import APIClient
 from cognite.client.data_classes import (
@@ -26,17 +26,17 @@ class EventsAPI(APIClient):
         type: str = None,
         subtype: str = None,
         metadata: Dict[str, str] = None,
-        asset_ids: List[int] = None,
-        asset_external_ids: List[str] = None,
-        asset_subtree_ids: List[int] = None,
-        asset_subtree_external_ids: List[str] = None,
-        data_set_ids: List[int] = None,
-        data_set_external_ids: List[str] = None,
+        asset_ids: Sequence[int] = None,
+        asset_external_ids: Sequence[str] = None,
+        asset_subtree_ids: Sequence[int] = None,
+        asset_subtree_external_ids: Sequence[str] = None,
+        data_set_ids: Sequence[int] = None,
+        data_set_external_ids: Sequence[str] = None,
         source: str = None,
         created_time: Union[Dict[str, Any], TimestampRange] = None,
         last_updated_time: Union[Dict[str, Any], TimestampRange] = None,
         external_id_prefix: str = None,
-        sort: List[str] = None,
+        sort: Sequence[str] = None,
         limit: int = None,
         partitions: int = None,
     ) -> Union[Iterator[Event], Iterator[EventList]]:
@@ -52,17 +52,17 @@ class EventsAPI(APIClient):
             type (str): Type of the event, e.g 'failure'.
             subtype (str): Subtype of the event, e.g 'electrical'.
             metadata (Dict[str, str]): Customizable extra data about the event. String key -> String value.
-            asset_ids (List[int]): Asset IDs of related equipments that this event relates to.
-            asset_external_ids (List[str]): Asset External IDs of related equipment that this event relates to.
-            asset_subtree_ids (List[int]): List of asset subtrees ids to filter on.
-            asset_subtree_external_ids (List[str]): List of asset subtrees external ids to filter on.
-            data_set_ids (List[int]): Return only events in the specified data sets with these ids.
-            data_set_external_ids (List[str]): Return only events in the specified data sets with these external ids.
+            asset_ids (Sequence[int]): Asset IDs of related equipments that this event relates to.
+            asset_external_ids (Sequence[str]): Asset External IDs of related equipment that this event relates to.
+            asset_subtree_ids (Sequence[int]): List of asset subtrees ids to filter on.
+            asset_subtree_external_ids (Sequence[str]): List of asset subtrees external ids to filter on.
+            data_set_ids (Sequence[int]): Return only events in the specified data sets with these ids.
+            data_set_external_ids (Sequence[str]): Return only events in the specified data sets with these external ids.
             source (str): The source of this event.
             created_time (Union[Dict[str, int], TimestampRange]):  Range between two timestamps. Possible keys are `min` and `max`, with values given as time stamps in ms.
             last_updated_time (Union[Dict[str, int], TimestampRange]):  Range between two timestamps. Possible keys are `min` and `max`, with values given as time stamps in ms.
             external_id_prefix (str): External Id provided by client. Should be unique within the project
-            sort (List[str]): Sort by array of selected fields. Ex: ["startTime:desc']. Default sort order is asc when ommitted. Filter accepts following field names: startTime, endTime, createdTime, lastUpdatedTime. We only support 1 field for now.
+            sort (Sequence[str]): Sort by array of selected fields. Ex: ["startTime:desc']. Default sort order is asc when ommitted. Filter accepts following field names: startTime, endTime, createdTime, lastUpdatedTime. We only support 1 field for now.
             limit (int, optional): Maximum number of events to return. Defaults to return all items.
             partitions (int): Retrieve assets in parallel using this number of workers. Also requires `limit=None` to be passed.
 
@@ -145,15 +145,15 @@ class EventsAPI(APIClient):
 
     def retrieve_multiple(
         self,
-        ids: Optional[List[int]] = None,
-        external_ids: Optional[List[str]] = None,
+        ids: Optional[Sequence[int]] = None,
+        external_ids: Optional[Sequence[str]] = None,
         ignore_unknown_ids: bool = False,
     ) -> EventList:
         """`Retrieve multiple events by id. <https://docs.cognite.com/api/v1/#operation/byIdsEvents>`_
 
         Args:
-            ids (List[int], optional): IDs
-            external_ids (List[str], optional): External IDs
+            ids (Sequence[int], optional): IDs
+            external_ids (Sequence[str], optional): External IDs
             ignore_unknown_ids (bool): Ignore IDs and external IDs that are not found rather than throw an exception.
 
         Returns:
@@ -186,17 +186,17 @@ class EventsAPI(APIClient):
         type: str = None,
         subtype: str = None,
         metadata: Dict[str, str] = None,
-        asset_ids: List[int] = None,
-        asset_external_ids: List[str] = None,
-        asset_subtree_ids: List[int] = None,
-        asset_subtree_external_ids: List[str] = None,
-        data_set_ids: List[int] = None,
-        data_set_external_ids: List[str] = None,
+        asset_ids: Sequence[int] = None,
+        asset_external_ids: Sequence[str] = None,
+        asset_subtree_ids: Sequence[int] = None,
+        asset_subtree_external_ids: Sequence[str] = None,
+        data_set_ids: Sequence[int] = None,
+        data_set_external_ids: Sequence[str] = None,
         source: str = None,
         created_time: Union[Dict[str, Any], TimestampRange] = None,
         last_updated_time: Union[Dict[str, Any], TimestampRange] = None,
         external_id_prefix: str = None,
-        sort: List[str] = None,
+        sort: Sequence[str] = None,
         partitions: int = None,
         limit: int = 25,
     ) -> EventList:
@@ -209,17 +209,17 @@ class EventsAPI(APIClient):
             type (str): Type of the event, e.g 'failure'.
             subtype (str): Subtype of the event, e.g 'electrical'.
             metadata (Dict[str, str]): Customizable extra data about the event. String key -> String value.
-            asset_ids (List[int]): Asset IDs of related equipments that this event relates to.
-            asset_external_ids (List[str]): Asset External IDs of related equipment that this event relates to.
-            asset_subtree_ids (List[int]): List of asset subtrees ids to filter on.
-            asset_subtree_external_ids (List[str]): List of asset subtrees external ids to filter on.
-            data_set_ids (List[int]): Return only events in the specified data sets with these ids.
-            data_set_external_ids (List[str]): Return only events in the specified data sets with these external ids.
+            asset_ids (Sequence[int]): Asset IDs of related equipments that this event relates to.
+            asset_external_ids (Sequence[str]): Asset External IDs of related equipment that this event relates to.
+            asset_subtree_ids (Sequence[int]): List of asset subtrees ids to filter on.
+            asset_subtree_external_ids (Sequence[str]): List of asset subtrees external ids to filter on.
+            data_set_ids (Sequence[int]): Return only events in the specified data sets with these ids.
+            data_set_external_ids (Sequence[str]): Return only events in the specified data sets with these external ids.
             source (str): The source of this event.
             created_time (Union[Dict[str, int], TimestampRange]):  Range between two timestamps. Possible keys are `min` and `max`, with values given as time stamps in ms.
             last_updated_time (Union[Dict[str, int], TimestampRange]):  Range between two timestamps. Possible keys are `min` and `max`, with values given as time stamps in ms.
             external_id_prefix (str): External Id provided by client. Should be unique within the project.
-            sort (List[str]): Sort by array of selected fields. Ex: ["startTime:desc']. Default sort order is asc when ommitted. Filter accepts following field names: startTime, endTime, createdTime, lastUpdatedTime. We only support 1 field for now.
+            sort (Sequence[str]): Sort by array of selected fields. Ex: ["startTime:desc']. Default sort order is asc when ommitted. Filter accepts following field names: startTime, endTime, createdTime, lastUpdatedTime. We only support 1 field for now.
             partitions (int): Retrieve events in parallel using this number of workers. Also requires `limit=None` to be passed.
             limit (int, optional): Maximum number of events to return. Defaults to 25. Set to -1, float("inf") or None
                 to return all items.
@@ -309,13 +309,13 @@ class EventsAPI(APIClient):
         return self._aggregate(filter=filter, cls=AggregateResult)
 
     def aggregate_unique_values(
-        self, filter: Union[EventFilter, Dict] = None, fields: List[str] = None
+        self, filter: Union[EventFilter, Dict] = None, fields: Sequence[str] = None
     ) -> List[AggregateUniqueValuesResult]:
         """`Aggregate unique values for events <https://docs.cognite.com/api/v1/#operation/aggregateEvents>`_
 
         Args:
             filter (Union[EventFilter, Dict]): Filter on events filter with exact match
-            fields (List[str]): The field name(s) to apply the aggregation on. Currently limited to one field.
+            fields (Sequence[str]): The field name(s) to apply the aggregation on. Currently limited to one field.
 
         Returns:
             List[AggregateUniqueValuesResult]: List of event aggregates
@@ -332,18 +332,18 @@ class EventsAPI(APIClient):
         return self._aggregate(filter=filter, fields=fields, aggregate="uniqueValues", cls=AggregateUniqueValuesResult)
 
     @overload
-    def create(self, event: List[Event]) -> EventList:
+    def create(self, event: Sequence[Event]) -> EventList:
         ...
 
     @overload
     def create(self, event: Event) -> Event:
         ...
 
-    def create(self, event: Union[Event, List[Event]]) -> Union[Event, EventList]:
+    def create(self, event: Union[Event, Sequence[Event]]) -> Union[Event, EventList]:
         """`Create one or more events. <https://docs.cognite.com/api/v1/#operation/createEvents>`_
 
         Args:
-            event (Union[Event, List[Event]]): Event or list of events to create.
+            event (Union[Event, Sequence[Event]]): Event or list of events to create.
 
         Returns:
             Union[Event, EventList]: Created event(s)
@@ -362,15 +362,15 @@ class EventsAPI(APIClient):
 
     def delete(
         self,
-        id: Union[int, List[int]] = None,
-        external_id: Union[str, List[str]] = None,
+        id: Union[int, Sequence[int]] = None,
+        external_id: Union[str, Sequence[str]] = None,
         ignore_unknown_ids: bool = False,
     ) -> None:
         """`Delete one or more events <https://docs.cognite.com/api/v1/#operation/deleteEvents>`_
 
         Args:
-            id (Union[int, List[int]): Id or list of ids
-            external_id (Union[str, List[str]]): External ID or list of external ids
+            id (Union[int, Sequence[int]): Id or list of ids
+            external_id (Union[str, Sequence[str]]): External ID or list of external ids
             ignore_unknown_ids (bool): Ignore IDs and external IDs that are not found rather than throw an exception.
 
         Returns:
@@ -390,18 +390,18 @@ class EventsAPI(APIClient):
         )
 
     @overload
-    def update(self, item: List[Union[Event, EventUpdate]]) -> EventList:
+    def update(self, item: Sequence[Union[Event, EventUpdate]]) -> EventList:
         ...
 
     @overload
     def update(self, item: Union[Event, EventUpdate]) -> Event:
         ...
 
-    def update(self, item: Union[Event, EventUpdate, List[Union[Event, EventUpdate]]]) -> Union[Event, EventList]:
+    def update(self, item: Union[Event, EventUpdate, Sequence[Union[Event, EventUpdate]]]) -> Union[Event, EventList]:
         """`Update one or more events <https://docs.cognite.com/api/v1/#operation/updateEvents>`_
 
         Args:
-            item (Union[Event, EventUpdate, List[Union[Event, EventUpdate]]]): Event(s) to update
+            item (Union[Event, EventUpdate, Sequence[Union[Event, EventUpdate]]]): Event(s) to update
 
         Returns:
             Union[Event, EventList]: Updated event(s)
