@@ -1,5 +1,5 @@
 import numbers
-from typing import TYPE_CHECKING, List, Optional, Union
+from typing import TYPE_CHECKING, Optional, Sequence, Union
 
 from cognite.client import utils
 from cognite.client._api_client import APIClient
@@ -58,12 +58,12 @@ class ServiceAccountsAPI(APIClient):
         return ServiceAccountList._load(self._get(url_path=self._RESOURCE_PATH).json()["items"])
 
     def create(
-        self, service_account: Union[ServiceAccount, List[ServiceAccount]]
+        self, service_account: Union[ServiceAccount, Sequence[ServiceAccount]]
     ) -> Union[ServiceAccount, ServiceAccountList]:
         """`Create one or more new service accounts. <https://docs.cognite.com/api/v1/#operation/createServiceAccounts>`_
 
         Args:
-            service_account (Union[ServiceAccount, List[ServiceAccount]]): The service account(s) to create.
+            service_account (Union[ServiceAccount, Sequence[ServiceAccount]]): The service account(s) to create.
 
         Returns:
             Union[ServiceAccount, ServiceAccountList]: The created service account(s).
@@ -80,11 +80,11 @@ class ServiceAccountsAPI(APIClient):
         """
         return self._create_multiple(list_cls=ServiceAccountList, resource_cls=ServiceAccount, items=service_account)
 
-    def delete(self, id: Union[int, List[int]]) -> None:
+    def delete(self, id: Union[int, Sequence[int]]) -> None:
         """`Delete one or more service accounts. <https://docs.cognite.com/api/v1/#operation/deleteServiceAccounts>`_
 
         Args:
-            id (Union[int, List[int]]): ID or list of IDs to delete.
+            id (Union[int, Sequence[int]]): ID or list of IDs to delete.
 
         Returns:
             None
@@ -128,11 +128,11 @@ class APIKeysAPI(APIClient):
         )
         return APIKeyList._load(res.json()["items"])
 
-    def create(self, service_account_id: Union[int, List[int]]) -> Union[APIKey, APIKeyList]:
+    def create(self, service_account_id: Union[int, Sequence[int]]) -> Union[APIKey, APIKeyList]:
         """`Create a new api key for one or more service accounts. <https://docs.cognite.com/api/v1/#operation/createApiKeys>`_
 
         Args:
-            service_account_id (Union[int, List[int]]): ID or list of IDs of service accounts to create an api key for.
+            service_account_id (Union[int, Sequence[int]]): ID or list of IDs of service accounts to create an api key for.
 
         Returns:
             Union[APIKey, APIKeyList]: API key or list of api keys.
@@ -146,18 +146,18 @@ class APIKeysAPI(APIClient):
                 >>> res = c.iam.api_keys.create(1)
         """
         if isinstance(service_account_id, numbers.Integral):
-            items = {"serviceAccountId": service_account_id}
-        elif isinstance(service_account_id, list):
+            items: Union[list, dict] = {"serviceAccountId": service_account_id}
+        elif isinstance(service_account_id, Sequence):
             items = [{"serviceAccountId": sa_id} for sa_id in service_account_id]
         else:
-            raise TypeError("service_account_id must be an int or a list of ints")
+            raise TypeError("service_account_id must be of type int or Sequence[int]")
         return self._create_multiple(list_cls=APIKeyList, resource_cls=APIKey, items=items)
 
-    def delete(self, id: Union[int, List[int]]) -> None:
+    def delete(self, id: Union[int, Sequence[int]]) -> None:
         """`Delete one or more api keys. <https://docs.cognite.com/api/v1/#operation/deleteApiKeys>`_
 
         Args:
-            id (Union[int, List[int]]): ID or list of IDs of api keys to delete.
+            id (Union[int, Sequence[int]]): ID or list of IDs of api keys to delete.
 
         Returns:
             None
@@ -196,11 +196,11 @@ class GroupsAPI(APIClient):
         res = self._get(self._RESOURCE_PATH, params={"all": all})
         return GroupList._load(res.json()["items"])
 
-    def create(self, group: Union[Group, List[Group]]) -> Union[Group, GroupList]:
+    def create(self, group: Union[Group, Sequence[Group]]) -> Union[Group, GroupList]:
         """`Create one or more groups. <https://docs.cognite.com/api/v1/#operation/createGroups>`_
 
         Args:
-            group (Union[Group, List[Group]]): Group or list of groups to create.
+            group (Union[Group, Sequence[Group]]): Group or list of groups to create.
         Returns:
             Union[Group, GroupList]: The created group(s).
 
@@ -217,11 +217,11 @@ class GroupsAPI(APIClient):
         """
         return self._create_multiple(list_cls=GroupList, resource_cls=Group, items=group)
 
-    def delete(self, id: Union[int, List[int]]) -> None:
+    def delete(self, id: Union[int, Sequence[int]]) -> None:
         """`Delete one or more groups. <https://docs.cognite.com/api/v1/#operation/deleteGroups>`_
 
         Args:
-            id (Union[int, List[int]]): ID or list of IDs of groups to delete.
+            id (Union[int, Sequence[int]]): ID or list of IDs of groups to delete.
 
         Returns:
             None
@@ -256,12 +256,12 @@ class GroupsAPI(APIClient):
         resource_path = utils._auxiliary.interpolate_and_url_encode(self._RESOURCE_PATH + "/{}/serviceaccounts", id)
         return ServiceAccountList._load(self._get(resource_path).json()["items"])
 
-    def add_service_account(self, id: int, service_account_id: Union[int, List[int]]) -> None:
+    def add_service_account(self, id: int, service_account_id: Union[int, Sequence[int]]) -> None:
         """`Add one or more service accounts to a group. <https://docs.cognite.com/api/v1/#operation/addServiceAccountsToGroup>`_
 
         Args:
             id (int): Add service accounts to the group with this id.
-            service_account_id (Union[int, List[int]]): Add these service accounts to the specified group.
+            service_account_id (Union[int, Sequence[int]]): Add these service accounts to the specified group.
 
         Returns:
             None
@@ -279,7 +279,7 @@ class GroupsAPI(APIClient):
         all_ids = IdentifierSequence.load(ids=service_account_id, external_ids=None).as_primitives()
         self._post(resource_path, json={"items": all_ids})
 
-    def remove_service_account(self, id: int, service_account_id: Union[int, List[int]]) -> None:
+    def remove_service_account(self, id: int, service_account_id: Union[int, Sequence[int]]) -> None:
         """`Remove one or more service accounts from a group. <https://docs.cognite.com/api/v1/#operation/removeServiceAccountsFromGroup>`_
 
         Args:
@@ -326,12 +326,12 @@ class SecurityCategoriesAPI(APIClient):
         return self._list(list_cls=SecurityCategoryList, resource_cls=SecurityCategory, method="GET", limit=limit)
 
     def create(
-        self, security_category: Union[SecurityCategory, List[SecurityCategory]]
+        self, security_category: Union[SecurityCategory, Sequence[SecurityCategory]]
     ) -> Union[SecurityCategory, SecurityCategoryList]:
         """`Create one or more security categories. <https://docs.cognite.com/api/v1/#operation/createSecurityCategories>`_
 
         Args:
-            security_category (Union[SecurityCategory, List[SecurityCategory]]): Security category or list of categories to create.
+            security_category (Union[SecurityCategory, Sequence[SecurityCategory]]): Security category or list of categories to create.
 
         Returns:
             Union[SecurityCategory, SecurityCategoryList]: The created security category or categories.
@@ -350,11 +350,11 @@ class SecurityCategoriesAPI(APIClient):
             list_cls=SecurityCategoryList, resource_cls=SecurityCategory, items=security_category
         )
 
-    def delete(self, id: Union[int, List[int]]) -> None:
+    def delete(self, id: Union[int, Sequence[int]]) -> None:
         """`Delete one or more security categories. <https://docs.cognite.com/api/v1/#operation/deleteSecurityCategories>`_
 
         Args:
-            id (Union[int, List[int]]): ID or list of IDs of security categories to delete.
+            id (Union[int, Sequence[int]]): ID or list of IDs of security categories to delete.
 
         Returns:
             None
@@ -408,11 +408,11 @@ class SessionsAPI(APIClient):
 
         return CreatedSessionList._load(self._post(self._RESOURCE_PATH, json).json()["items"])[0]
 
-    def revoke(self, id: Union[int, List[int]]) -> SessionList:
+    def revoke(self, id: Union[int, Sequence[int]]) -> SessionList:
         """`Revoke access to a session. Revocation of a session may in some cases take up to 1 hour to take effect. <https://docs.cognite.com/api/v1/#operation/revokeSessions>`_
 
         Args:
-            id (Union[int, List[int]): Id or list of session ids
+            id (Union[int, Sequence[int]): Id or list of session ids
 
         Returns:
             List of revoked sessions. If the user does not have the sessionsAcl:LIST  capability,
