@@ -1,5 +1,5 @@
 import copy
-from typing import Any, Dict, Iterator, List, Optional, Union, cast
+from typing import Any, Dict, Iterator, List, Optional, Sequence, Union, cast
 
 from cognite.client import utils
 from cognite.client._api_client import APIClient
@@ -18,11 +18,11 @@ class RelationshipsAPI(APIClient):
 
     def _create_filter(
         self,
-        source_external_ids: List[str] = None,
-        source_types: List[str] = None,
-        target_external_ids: List[str] = None,
-        target_types: List[str] = None,
-        data_set_ids: List[Dict[str, Any]] = None,
+        source_external_ids: Sequence[str] = None,
+        source_types: Sequence[str] = None,
+        target_external_ids: Sequence[str] = None,
+        target_types: Sequence[str] = None,
+        data_set_ids: Sequence[Dict[str, Any]] = None,
         start_time: Dict[str, int] = None,
         end_time: Dict[str, int] = None,
         confidence: Dict[str, int] = None,
@@ -48,12 +48,12 @@ class RelationshipsAPI(APIClient):
 
     def __call__(
         self,
-        source_external_ids: List[str] = None,
-        source_types: List[str] = None,
-        target_external_ids: List[str] = None,
-        target_types: List[str] = None,
-        data_set_ids: List[int] = None,
-        data_set_external_ids: List[str] = None,
+        source_external_ids: Sequence[str] = None,
+        source_types: Sequence[str] = None,
+        target_external_ids: Sequence[str] = None,
+        target_types: Sequence[str] = None,
+        data_set_ids: Sequence[int] = None,
+        data_set_external_ids: Sequence[str] = None,
         start_time: Dict[str, int] = None,
         end_time: Dict[str, int] = None,
         confidence: Dict[str, int] = None,
@@ -71,12 +71,12 @@ class RelationshipsAPI(APIClient):
         Fetches relationships as they are iterated over, so you keep a limited number of relationships in memory.
 
         Args:
-            source_external_ids (List[str]): Include relationships that have any of these values in their source External Id field
-            source_types (List[str]): Include relationships that have any of these values in their source Type field
-            target_external_ids (List[str]): Include relationships that have any of these values in their target External Id field
-            target_types (List[str]): Include relationships that have any of these values in their target Type field
-            data_set_ids (List[int]): Return only relationships in the specified data sets with these ids.
-            data_set_external_ids (List[str]): Return only relationships in the specified data sets with these external ids.
+            source_external_ids (Sequence[str]): Include relationships that have any of these values in their source External Id field
+            source_types (Sequence[str]): Include relationships that have any of these values in their source Type field
+            target_external_ids (Sequence[str]): Include relationships that have any of these values in their target External Id field
+            target_types (Sequence[str]): Include relationships that have any of these values in their target Type field
+            data_set_ids (Sequence[int]): Return only relationships in the specified data sets with these ids.
+            data_set_external_ids (Sequence[str]): Return only relationships in the specified data sets with these external ids.
             start_time (Dict[str, int]): Range between two timestamps, minimum and maximum milli seconds (inclusive)
             end_time (Dict[str, int]): Range between two timestamps, minimum and maximum milli seconds (inclusive)
             confidence (Dict[str, int]): Range to filter the field for. (inclusive)
@@ -166,11 +166,11 @@ class RelationshipsAPI(APIClient):
             other_params={"fetchResources": fetch_resources},
         )
 
-    def retrieve_multiple(self, external_ids: List[str], fetch_resources: bool = False) -> RelationshipList:
+    def retrieve_multiple(self, external_ids: Sequence[str], fetch_resources: bool = False) -> RelationshipList:
         """`Retrieve multiple relationships by external id.  <https://docs.cognite.com/api/v1/#operation/byidsRelationships>`_
 
         Args:
-            external_ids (List[str]): External IDs
+            external_ids (Sequence[str]): External IDs
             fetch_resources (bool): if true, will try to return the full resources referenced by the relationship in the
                 source and target fields.
 
@@ -195,12 +195,12 @@ class RelationshipsAPI(APIClient):
 
     def list(
         self,
-        source_external_ids: List[str] = None,
-        source_types: List[str] = None,
-        target_external_ids: List[str] = None,
-        target_types: List[str] = None,
-        data_set_ids: List[int] = None,
-        data_set_external_ids: List[str] = None,
+        source_external_ids: Sequence[str] = None,
+        source_types: Sequence[str] = None,
+        target_external_ids: Sequence[str] = None,
+        target_types: Sequence[str] = None,
+        data_set_ids: Sequence[int] = None,
+        data_set_external_ids: Sequence[str] = None,
         start_time: Dict[str, int] = None,
         end_time: Dict[str, int] = None,
         confidence: Dict[str, int] = None,
@@ -215,12 +215,12 @@ class RelationshipsAPI(APIClient):
         """`Lists relationships stored in the project based on a query filter given in the payload of this request. Up to 1000 relationships can be retrieved in one operation.  <https://docs.cognite.com/api/v1/#operation/listRelationships>`_
 
         Args:
-            source_external_ids (List[str]): Include relationships that have any of these values in their source External Id field
-            source_types (List[str]): Include relationships that have any of these values in their source Type field
-            target_external_ids (List[str]): Include relationships that have any of these values in their target External Id field
-            target_types (List[str]): Include relationships that have any of these values in their target Type field
-            data_set_ids (List[int]): Return only relationships in the specified data sets with these ids.
-            data_set_external_ids (List[str]): Return only relationships in the specified data sets with these external ids.
+            source_external_ids (Sequence[str]): Include relationships that have any of these values in their source External Id field
+            source_types (Sequence[str]): Include relationships that have any of these values in their source Type field
+            target_external_ids (Sequence[str]): Include relationships that have any of these values in their target External Id field
+            target_types (Sequence[str]): Include relationships that have any of these values in their target Type field
+            data_set_ids (Sequence[int]): Return only relationships in the specified data sets with these ids.
+            data_set_external_ids (Sequence[str]): Return only relationships in the specified data sets with these external ids.
             start_time (Dict[str, int]): Range between two timestamps, minimum and maximum milli seconds (inclusive)
             end_time (Dict[str, int]): Range between two timestamps, minimum and maximum milli seconds (inclusive)
             confidence (Dict[str, int]): Range to filter the field for. (inclusive)
@@ -318,11 +318,13 @@ class RelationshipsAPI(APIClient):
             other_params={"fetchResources": fetch_resources},
         )
 
-    def create(self, relationship: Union[Relationship, List[Relationship]]) -> Union[Relationship, RelationshipList]:
+    def create(
+        self, relationship: Union[Relationship, Sequence[Relationship]]
+    ) -> Union[Relationship, RelationshipList]:
         """`Create one or more relationships. <https://docs.cognite.com/api/v1/#operation/createRelationships>`_
 
         Args:
-            relationship (Union[Relationship, List[Relationship]]): Relationship or list of relationships to create.
+            relationship (Union[Relationship, Sequence[Relationship]]): Relationship or list of relationships to create.
                 Note: the source_type and target_type field in the Relationship(s) can be any string among "Asset", "TimeSeries", "FileMetadata", "Event", "Sequence"
 
         Returns:
@@ -339,8 +341,8 @@ class RelationshipsAPI(APIClient):
                 >>> flowrel2 = Relationship(external_id="flow_2", source_external_id="source_ext_id", source_type="asset", target_external_id="target_ext_id", target_type="event", confidence=0.1, data_set_id=1234)
                 >>> res = c.relationships.create([flowrel1,flowrel2])
         """
-        utils._auxiliary.assert_type(relationship, "relationship", [Relationship, list])
-        if isinstance(relationship, list):
+        utils._auxiliary.assert_type(relationship, "relationship", [Relationship, Sequence])
+        if isinstance(relationship, Sequence):
             relationship = [r._validate_resource_types() for r in relationship]
         else:
             relationship = relationship._validate_resource_types()
@@ -348,13 +350,13 @@ class RelationshipsAPI(APIClient):
         return self._create_multiple(list_cls=RelationshipList, resource_cls=Relationship, items=relationship)
 
     def update(
-        self, item: Union[Relationship, RelationshipUpdate, List[Union[Relationship, RelationshipUpdate]]]
+        self, item: Union[Relationship, RelationshipUpdate, Sequence[Union[Relationship, RelationshipUpdate]]]
     ) -> Union[Relationship, RelationshipList]:
         """`Update one or more relationships <https://docs.cognite.com/api/v1/#operation/updateRelationships>`_
         Currently, a full replacement of labels on a relationship is not supported (only partial add/remove updates). See the example below on how to perform partial labels update.
 
         Args:
-            item (Union[Relationship, RelationshipUpdate, List[Union[Relationship, RelationshipUpdate]]]): Relationships(s) to update
+            item (Union[Relationship, RelationshipUpdate, Sequence[Union[Relationship, RelationshipUpdate]]]): Relationships(s) to update
 
         Returns:
             Union[Relationship, RelationshipsList]: Updated relationship(s)
@@ -399,11 +401,11 @@ class RelationshipsAPI(APIClient):
             list_cls=RelationshipList, resource_cls=Relationship, update_cls=RelationshipUpdate, items=item
         )
 
-    def delete(self, external_id: Union[str, List[str]], ignore_unknown_ids: bool = False) -> None:
+    def delete(self, external_id: Union[str, Sequence[str]], ignore_unknown_ids: bool = False) -> None:
         """`Delete one or more relationships. <https://docs.cognite.com/api/v1/#operation/deleteRelationships>`_
 
         Args:
-            external_id (Union[str, List[str]]): External ID or list of external ids
+            external_id (Union[str, Sequence[str]]): External ID or list of external ids
             ignore_unknown_ids (bool): Ignore external IDs that are not found rather than throw an exception.
         Returns:
             None
